-- Prozedur/Funktion PROC_DEL_ELEMENT_GEOMETRY erstellen.
If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'PROC_DEL_ELEMENT_GEOMETRY'
            AND type = 'P')
	DROP PROCEDURE PROC_DEL_ELEMENT_GEOMETRY
GO 
CREATE PROCEDURE PROC_DEL_ELEMENT_GEOMETRY
	@ELEMENT                                 NUMERIC 
AS 
	BEGIN
		SET NOCOUNT ON
		-- Declare the variables to store the values returned by FETCH.
		DECLARE @EDGELINE NUMERIC
		DECLARE edges_cursor CURSOR FOR 
			SELECT EDGELINE	FROM EDGELINE WHERE (ELEMENT = @ELEMENT)
		
		DELETE FROM FACE WHERE ELEMENT = @ELEMENT 
		DELETE FROM EXTRUSION WHERE ELEMENT = @ELEMENT 

		OPEN edges_cursor 
		FETCH NEXT FROM edges_cursor INTO @EDGELINE
		WHILE (@@FETCH_STATUS <> -1)
		BEGIN
			DELETE FROM EDGETO WHERE EDGELINE = @EDGELINE 
			FETCH NEXT FROM edges_cursor INTO @EDGELINE
		END
		CLOSE edges_cursor
		DEALLOCATE edges_cursor
		
		DELETE FROM EDGELINE WHERE ELEMENT = @ELEMENT 
		DELETE FROM VERTEX WHERE ELEMENT = @ELEMENT 
	
		SET NOCOUNT OFF
	END
GO


-- Prozedur/Funktion PROC_DEL_ELEMENT_TEXTURE erstellen.
If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'PROC_DEL_ELEMENT_TEXTURE'
            AND type = 'P')
	DROP PROCEDURE PROC_DEL_ELEMENT_TEXTURE
GO 
CREATE PROCEDURE PROC_DEL_ELEMENT_TEXTURE
	@ELEMENT                                 NUMERIC 
AS 
	BEGIN
		SET NOCOUNT ON
		DECLARE @TEXTURE NUMERIC
		DECLARE texs CURSOR FOR 
			SELECT TEXTURE FROM TEXTURE WHERE (ELEMENT = @ELEMENT)
		OPEN texs 
		FETCH NEXT FROM texs INTO @TEXTURE
		WHILE (@@FETCH_STATUS <> -1)
		BEGIN
            update FACE set TEXTURE = NULL where TEXTURE = @TEXTURE

			DECLARE @COLOR NUMERIC
			DECLARE col CURSOR FOR 
				SELECT COLOR FROM TEXTURE WHERE TEXTURE = @TEXTURE and COLOR != NULL
			OPEN col 
			FETCH NEXT FROM col INTO @COLOR
			WHILE (@@FETCH_STATUS <> -1)
			BEGIN
				update TEXTURE set COLOR = NULL where COLOR = @COLOR
				delete from COLOR where COLOR = @COLOR
				FETCH NEXT FROM col INTO @COLOR
			END
			CLOSE col
			DEALLOCATE col

			FETCH NEXT FROM texs INTO @TEXTURE
		END
		CLOSE texs
		DEALLOCATE texs

        delete from TEXTURE where ELEMENT = @ELEMENT
        delete from TEXCOORD where ELEMENT = @ELEMENT
	
		SET NOCOUNT OFF
	END
GO


-- Prozedur/Funktion PROC_DEL_ELEMENT erstellen.
If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'PROC_DEL_ELEMENT'
            AND type = 'P')
	DROP PROCEDURE PROC_DEL_ELEMENT
GO 
CREATE PROCEDURE PROC_DEL_ELEMENT
	@ELEMENT                                 NUMERIC 
AS 
	BEGIN
		SET NOCOUNT ON
		EXECUTE PROC_DEL_ELEMENT_GEOMETRY @ELEMENT
		EXECUTE PROC_DEL_ELEMENT_TEXTURE @ELEMENT
		delete from ELEMENTCONNECT where ELEMENT = @ELEMENT or ELEMENTCONNECT = @ELEMENT
		delete from ELEMENT where ELEMENT = @ELEMENT
		SET NOCOUNT OFF
	END
GO


-- Prozedur/Funktion PROC_DEL_OBJECT erstellen.
If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'PROC_DEL_OBJECT'
            AND type = 'P')
	DROP PROCEDURE PROC_DEL_OBJECT
GO 
CREATE PROCEDURE PROC_DEL_OBJECT
	@OBJECT                                 NUMERIC 
AS 
	BEGIN
		SET NOCOUNT ON
		DECLARE @ELEMENT NUMERIC
		DECLARE eles_cursor CURSOR FOR 
			SELECT ELEMENT	FROM ELEMENT WHERE (OBJECT = @OBJECT)
		OPEN eles_cursor 
		FETCH NEXT FROM eles_cursor INTO @ELEMENT
		WHILE (@@FETCH_STATUS <> -1)
		BEGIN
			EXECUTE PROC_DEL_ELEMENT @ELEMENT
			FETCH NEXT FROM eles_cursor INTO @ELEMENT
		END
		CLOSE eles_cursor
		DEALLOCATE eles_cursor

		delete from OBJECT where OBJECT = @OBJECT

		SET NOCOUNT OFF
	END
GO


-- Prozedur/Funktion PROC_DEL_UNIT erstellen.
If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'PROC_DEL_UNIT'
            AND type = 'P')
	DROP PROCEDURE PROC_DEL_UNIT
GO 
CREATE PROCEDURE PROC_DEL_UNIT
	@UNIT                                 NUMERIC 
AS 
	BEGIN
		SET NOCOUNT ON
		DECLARE @OBJECT NUMERIC
		DECLARE objs_cursor CURSOR FOR 
			SELECT OBJECT FROM OBJECT WHERE (UNIT = @UNIT)
		OPEN objs_cursor 
		FETCH NEXT FROM objs_cursor INTO @OBJECT
		WHILE (@@FETCH_STATUS <> -1)
		BEGIN
			EXECUTE PROC_DEL_OBJECT @OBJECT
			FETCH NEXT FROM objs_cursor INTO @OBJECT
		END
		CLOSE objs_cursor
		DEALLOCATE objs_cursor

		delete from UNITVERSION where UNIT = @UNIT
		delete from MODELUNIT where UNIT = @UNIT
		delete from UNIT where UNIT = @UNIT

		SET NOCOUNT OFF
	END
GO


-- Prozedur/Funktion PROC_DEL_UNITVERSION erstellen.
If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'PROC_DEL_UNITVERSION'
            AND type = 'P')
	DROP PROCEDURE PROC_DEL_UNITVERSION
GO 
CREATE PROCEDURE PROC_DEL_UNITVERSION
	@UNITVERSION                                 NUMERIC 
AS 
	BEGIN
		SET NOCOUNT ON
		DECLARE @OBJECT NUMERIC
		DECLARE objs_cursor CURSOR FOR 
			SELECT OBJECT FROM OBJECT WHERE (UNITVERSION = @UNITVERSION)
		OPEN objs_cursor 
		FETCH NEXT FROM objs_cursor INTO @OBJECT
		WHILE (@@FETCH_STATUS <> -1)
		BEGIN
			EXECUTE PROC_DEL_OBJECT @OBJECT
			FETCH NEXT FROM objs_cursor INTO @OBJECT
		END
		CLOSE objs_cursor
		DEALLOCATE objs_cursor

		delete from UNITVERSION where UNIT = @UNITVERSION

		SET NOCOUNT OFF
	END
GO

