-- Neue Tabelle VERTEX erstellen.
-- VERTEX : Table of VERTEX  
create table VERTEX (
	VERTEX NUMERIC(12,0) IDENTITY(1,1) not null,
	WORLD_LONG NUMERIC(11,3) default 0 not null,
	WORLD_LAT NUMERIC(11,3) default 0 not null,
	WORLD_ELEV NUMERIC(11,3) default 0 not null,
	ELEMENT NUMERIC(12,0) not null, constraint VERTEX_PK primary key (VERTEX) ); 

-- Neue Tabelle UNITVERSION erstellen.
-- UNITVERSION : Table of UNITVERSION  
create table UNITVERSION (
	UNITVERSION NUMERIC(12,0) IDENTITY(1,1) not null,
	VERSIONNUMBER NUMERIC(12,0) default 0 not null,
	VERSIONDATE DATETIME not null,
	UNIT NUMERIC(12,0) not null,
	STATE NUMERIC(2,0) not null,
	COMMENT VARCHAR(256) default 'Created' null, constraint UNITVERSION_PK primary key (UNITVERSION) ); 


-- Neue Tabelle UNITTREE erstellen.
-- UNITTREE : Table of UNITTREE  
create table UNITTREE (
	PAGE NUMERIC not null,
	LEV NUMERIC null,
	PARENT NUMERIC null,
	USEDSPACE NUMERIC null,
	BRANCHES VARBINARY(MAX) null,
	CHILDMBBS VARBINARY(MAX) null); 

-- Neue Tabelle UNITGIS erstellen.
-- UNITGIS : Table of UNITGIS  
create table UNITGIS (
	GISKEY VARCHAR(64) not null,
	UNIT NUMERIC(12,0) not null); 

-- Neue Tabelle UNITEXPORT erstellen.
-- UNITEXPORT : Table of UNITEXPORT  
create table UNITEXPORT (
	LOD NUMERIC(2,0) not null,
	TYPE NUMERIC(2,0) not null,
	EXPORTDATA NUMERIC(12,0) not null,
	UNIT NUMERIC(12,0) not null); 

-- Neue Tabelle UNIT erstellen.
-- UNIT : Table of UNIT  
create table UNIT (
	UNIT NUMERIC(12,0) IDENTITY(1,1) not null,
	WORLD_LONG NUMERIC(11,3) not null,
	WORLD_LAT NUMERIC(11,3) not null,
	WORLD_ELEV NUMERIC(11,3) not null,
	UNIT_NUMBER NUMERIC(9,0) null,
	NAMEN VARCHAR(255) null,
	WEB_DESCRIPTION VARCHAR(MAX) null,
	WEB_LINK VARCHAR(255) null,
	UNITID VARCHAR(255) not null, constraint PK_UNIT2 primary key (UNIT) ); 

-- Neue Tabelle TEXTURE erstellen.
-- TEXTURE : Table of TEXTURE  
create table TEXTURE (
	TEXTURE NUMERIC(12,0) IDENTITY(1,1) not null,
	IMAGE NUMERIC(12,0) null,
	COLOR NUMERIC(12,0) null,
	TRANSPARENCY NUMERIC(4,3) default 0 not null,
	DEF NUMERIC(1,0) null,
	ELEMENT NUMERIC(12,0) not null, constraint TEXTURE_PK primary key (TEXTURE) ); 

-- Neue Tabelle TEXCOORD erstellen.
-- TEXCOORD : Table of TEXCOORD  
create table TEXCOORD (
	TEXCOORD NUMERIC(12,0) IDENTITY(1,1) not null,
	ELEMENT NUMERIC(12,0) not null,
	X NUMERIC(15,7) not null,
	Y NUMERIC(15,7) not null, constraint PK_TEXCOORD62 primary key (TEXCOORD) ); 

-- Neue Tabelle OBJECTCLASS erstellen.
-- OBJECTCLASS : Table of OBJECTCLASS  
create table OBJECTCLASS (
	OBJECTCLASS NUMERIC(3,0) not null,
	DESCRIPTION VARCHAR(255) null, constraint PK_OBJECTCLASS4 primary key (OBJECTCLASS) ); 

-- Neue Tabelle OBJECT erstellen.
-- OBJECT : Table of OBJECT  
create table OBJECT (
	OBJECT NUMERIC(9,0) IDENTITY(1,1) not null,
	UNIT NUMERIC(12,0) not null,
	OBJECTCLASS NUMERIC(3,0) not null,
	WORLD_LONG NUMERIC(11,3) default 0 not null,
	WORLD_LAT NUMERIC(11,3) default 0 not null,
	WORLD_ELEV NUMERIC(11,3) default 0 not null,
	BOUNDARY VARBINARY(MAX) null,
	BOUNDARY_SIZE NUMERIC(5,0) default 0 not null,
	UNITVERSION NUMERIC(12,0) not null, constraint OBJECT_PK primary key (OBJECT) ); 

-- Neue Tabelle MODELUNIT erstellen.
-- MODELUNIT : Table of MODELUNIT
-- 	ELEV_SHIFT : derives from elevation difference between master area and model area (generalization)  
create table MODELUNIT (
	MODEL NUMERIC(6,0) not null,
	ELEV_SHIFT NUMERIC(8,3) null,
	UNIT NUMERIC(12,0) not null); 

-- Neue Tabelle MODEL erstellen.
-- MODEL : Table of MODEL  
create table MODEL (
	MODEL NUMERIC(6,0) IDENTITY(1,1) not null,
	AREA NUMERIC(6,0) null,
	NAMEN VARCHAR(255) null,
	TEXTUREPATH VARCHAR(255) null,
	IMAGE NUMERIC(12,0) null,
	IMAGE_AREA NUMERIC(11,0) null,
	IMAGE_ROOF NUMERIC(11,0) null, constraint MODEL_PK primary key (MODEL) ); 

-- Neue Tabelle LOD erstellen.
-- LOD : Table of LOD  
create table LOD (
	LOD NUMERIC(2,0) not null,
	NAME VARCHAR(255) null, constraint LOD_PK primary key (LOD) ); 

-- Neue Tabelle INTERIORORIENTATION erstellen.
-- INTERIORORIENTATION : Table of INTERIORORIENTATION  
create table INTERIORORIENTATION (
	INTERIORORIENTATION NUMERIC(12,0) IDENTITY(1,1) not null,
	FOCAL_LENGTH NUMERIC(10,5) not null,
	IRP_X NUMERIC(10,5) not null,
	IRP_Y NUMERIC(10,5) not null,
	CAMERA VARCHAR(256) null,
	CALIBRATION_DATE DATETIME null, constraint INTERIORORIENTATION_PK primary key (INTERIORORIENTATION) ); 

-- Neue Tabelle mit Installationsinfos + Lizenz (wird nur eine einzige Zeile haben) erstellen
create table INST_INFO (
	SCHEMA_VERSION NUMERIC(2,1) not null,
	LICENSE_KEY VARBINARY(MAX),
	APP_KEY_COOKIE VARBINARY(MAX),
	TEXTURE_PATH VARCHAR(260) not null);
	
-- Neue Tabelle IMGPYRAMIDLEVEL erstellen.
-- IMGPYRAMIDLEVEL : Table of IMGPYRAMIDLEVEL  
create table IMGPYRAMIDLEVEL (
	RESOLUTION NUMERIC(9,0) not null, constraint PK_IMGPYRAMIDLEVEL primary key (RESOLUTION) ); 

-- Neue Tabelle IMGPYRAMID erstellen.
-- IMGPYRAMID : Table of IMGPYRAMID  
create table IMGPYRAMID (
	DIM_X NUMERIC(6,0) not null,
	DIM_Y NUMERIC(6,0) not null,
	CONTENT VARBINARY(MAX) null,
	RESOLUTION NUMERIC(9,0) null,
	IMAGE NUMERIC(12,0) not null); 

-- Neue Tabelle IMGORIENTATIONCONNECT erstellen.
-- IMGORIENTATIONCONNECT : Table of IMGORIENTATIONCONNECT  
create table IMGORIENTATIONCONNECT (
	IMGORIENTATIONCONNECT NUMERIC(12,0) IDENTITY(1,1) not null,
	IMGORIENTATION NUMERIC(12,0) not null,
	EXTERIORORIENTATION NUMERIC(12,0) not null,
	INTERIORORIENTATION NUMERIC(12,0) null,
	AFFINETRAFO NUMERIC(12,0) not null, constraint IMGORIENTATIONCONNECT_PK primary key (IMGORIENTATIONCONNECT) ); 

-- Neue Tabelle IMGORIENTATION erstellen.
-- IMGORIENTATION : Table of IMGORIENTATION  
create table IMGORIENTATION (
	IMAGE NUMERIC(12,0) not null,
	IMGORIENTATION NUMERIC(12,0) IDENTITY(1,1) not null,
	PROJTYPE NUMERIC(2,0) default 0 not null,
	SCANOFFSET_X NUMERIC(11,3) null,
	SCANOFFSET_Y NUMERIC(11,3) null,
	SUBIMAGEOFFSET_X NUMERIC(11,3) null,
	SUBIMAGEOFFSET_Y NUMERIC(11,3) null,
	ORTHO_CENTREOFFSET_X NUMERIC(11,3) null,
	ORTHO_CENTREOFFSET_Y NUMERIC(11,3) null,
	ORTHO_PIXELSIZE NUMERIC(9,0) null, constraint IMGORIENTATION_PK primary key (IMGORIENTATION) );

-- Neue Tabelle IMAGE erstellen.
-- IMAGE : Table of IMAGE  
create table IMAGE (
	IMAGE NUMERIC(12,0) IDENTITY(1,1) not null,
	RESOLUTION NUMERIC(9,0) not null,
	TYPE NUMERIC(2,0) not null,
	DESCRIPTION VARCHAR(MAX) null,
	NAMEN VARCHAR(256) null,
	PREVIEW VARBINARY(MAX) null,
	REFERENCE VARCHAR(256) null, constraint IMAGE_PK primary key (IMAGE) ); 

-- Neue Tabelle FACE erstellen.
-- FACE : Table of FACE  
create table FACE (
	FACE NUMERIC(12,0) IDENTITY(1,1) not null,
	VERTEX1 NUMERIC(9,0) null,
	VERTEX2 NUMERIC(9,0) null,
	VERTEX3 NUMERIC(9,0) null,
	ELEMENT NUMERIC(12,0) not null,
	TEXTURE NUMERIC(12,0) null,
	TEXCOORD1 NUMERIC(9,0) null,
	TEXCOORD2 NUMERIC(9,0) null,
	TEXCOORD3 NUMERIC(9,0) null, constraint FACE_PK primary key (FACE) ); 

-- Neue Tabelle EXTRUSION erstellen.
-- EXTRUSION : Table of EXTRUSION
-- 	EXTRUSION_TYPE : A= Extrude to area
-- 	P= Extrude to parent element  
create table EXTRUSION (
	DIR_LONG NUMERIC(5,4) not null,
	DIR_LAT NUMERIC(5,4) not null,
	DIR_ELEV NUMERIC(5,4) not null,
	EXTRUSION_TYPE CHAR(1) not null,
	ELEMENT NUMERIC(12,0) not null, constraint PK_EXTRUSION1 primary key (ELEMENT) ); 

-- Neue Tabelle EXTERIORORIENTATION erstellen.
-- EXTERIORORIENTATION : Table of EXTERIORORIENTATION  
create table EXTERIORORIENTATION (
	EXTERIORORIENTATION NUMERIC(12,0) IDENTITY(1,1) not null,
	ERP_X NUMERIC(11,3) not null,
	ERP_Y NUMERIC(11,3) not null,
	ERP_Z NUMERIC(11,3) not null,
	ANGLE_TYPE NUMERIC(2,0) not null,
	PRIM_ANGLE NUMERIC(10,7) not null,
	SEC_ANGLE NUMERIC(10,7) not null,
	TERT_ANGLE NUMERIC(10,7) not null, constraint EXTERIORORIENTATION_PK primary key (EXTERIORORIENTATION) );

-- Neue Tabelle EXPORTDATA erstellen.
-- EXPORTDATA : Table of EXPORTDATA  
create table EXPORTDATA (
	EXPORTDATA NUMERIC(12,0) IDENTITY(1,1) not null,
	DATA VARCHAR(MAX) not null, constraint EXPORTDATA_PK primary key (EXPORTDATA) ); 

-- Neue Tabelle ELEMENTCONNECT erstellen.
-- ELEMENTCONNECT : Table of ELEMENTCONNECT  
create table ELEMENTCONNECT (
	ELEMENT NUMERIC(12,0) not null,
	ELEMENTCONNECT NUMERIC(12,0) not null); 

-- Neue Tabelle ELEMENTCLASS erstellen.
-- ELEMENTCLASS : Table of ELEMENTCLASS  
create table ELEMENTCLASS (
	ELEMENTCLASS NUMERIC(3,0) not null,
	DESCRIPTION VARCHAR(255) null, constraint PK_ELEMENTCLASS3 primary key (ELEMENTCLASS) ); 

-- Neue Tabelle ELEMENT erstellen.
-- ELEMENT : Table of ELEMENT
-- 	"ACTION" : 0=Extend Parent  1=Replace Parent
-- 	TYPE : 1=Polygon  2=Surface  3=Extrusion  
create table ELEMENT (
	ELEMENT NUMERIC(12,0) IDENTITY(1,1) not null,
	OBJECT NUMERIC(9,0) not null,
	PARENT NUMERIC(12,0) null,
	ACTION CHAR(1) null,
	TYPE NUMERIC(4,0) not null,
	ELEMENTCLASS NUMERIC(3,0) not null,
	LOD NUMERIC(2,0) not null, 
	ELEV_LOD_BLOCK NUMERIC(11,3) null, constraint PK_ELEMENT primary key (ELEMENT) ); 

-- Neue Tabelle EDGETO erstellen.
-- EDGETO : Table of EDGETO  
create table EDGETO (
	EDGELINE NUMERIC(12,0) not null,
	ORDERING NUMERIC(4,0) not null,
	VERTEX NUMERIC(12,0) not null); 

-- Neue Tabelle EDGELINE erstellen.
-- EDGELINE : Table of EDGELINE
-- 	TYPE : 0=Structure (normale Dachlinien)  1=Contour (Traufe auen)  2=Cutout (Traufe innen) 3=Footprint (From Extrusion)
-- 	CODE : 100=Traufe  200=First  300=Dach
-- 	500=Grundriss  
create table EDGELINE (
	EDGELINE NUMERIC(12,0) IDENTITY(1,1) not null,
	TYPE NUMERIC(4,0) null,
	VERTEX NUMERIC(12,0) not null,
	ELEMENT NUMERIC(12,0) not null, constraint EDGELINE_PK primary key (EDGELINE) ); 

-- Neue Tabelle STREET_TEMPLATE erstellen.
-- STREET_TEMPLATE : Table of STREET_TEMPLATE  
create table STREET_TEMPLATE (
	STREET_KEY VARCHAR(16) not null,
	NAME VARCHAR(256) not null); 

-- Neue Tabelle ADDRESS_TEMPLATE erstellen.
-- ADDRESS_TEMPLATE : Table of ADDRESS_TEMPLATE  
create table ADDRESS_TEMPLATE (
	OBJECT_ID VARCHAR(16) not null,
	STREET_KEY VARCHAR(16) null,
	STREET_NUMBER VARCHAR(10) null,
	ADR_X NUMERIC(11,3) null,
	ADR_Y NUMERIC(11,3) null,
	OBJ_X NUMERIC(11,3) not null,
	OBJ_Y NUMERIC(11,3) not null); 

-- Neue Tabelle BREAKPOINT erstellen.
-- BREAKPOINT : Table of BREAKPOINT  
create table BREAKPOINT (
	BREAKPOINT NUMERIC(12,0) IDENTITY(1,1) not null,
	WORLD_LAT NUMERIC(11,3) not null,
	WORLD_LONG NUMERIC(11,3) not null,
	WORLD_ELEV NUMERIC(11,3) not null,
	AREA NUMERIC(6,0) null, constraint BREAKPOINT_PK primary key (BREAKPOINT) ); 

-- Neue Tabelle BREAKLINE erstellen.
-- BREAKLINE : Table of BREAKLINE  
create table BREAKLINE (
	BREAKLINE NUMERIC(12,0) IDENTITY(1,1) not null,
	BREAKPOINT_START NUMERIC(12,0) null,
	BREAKPOINT_END NUMERIC(12,0) null,
	AREA NUMERIC(6,0) null, constraint BREAKLINE_PK primary key (BREAKLINE) ); 

-- Neue Tabelle AREAEXPORT erstellen.
-- AREAEXPORT : Table of AREAEXPORT  
create table AREAEXPORT (
	AREA NUMERIC(6,0) not null,
	TYPE NUMERIC(2,0) not null,
	EXPORTDATA NUMERIC(12,0) not null); 

-- Neue Tabelle AREA erstellen.
-- AREA : Table of AREA  
create table AREA (
	AREA NUMERIC(6,0) IDENTITY(1,1) not null,
	REF_LONG NUMERIC(11,3) null,
	REF_LAT NUMERIC(11,3) null,
	DELTA_LONG NUMERIC(11,3) null,
	DELTA_LAT NUMERIC(11,3) null,
	DIM_LONG NUMERIC(11,0) null,
	DIM_LAT NUMERIC(11,0) null,
	DTM_POINTCOUNT NUMERIC(11,0) null,
	DTM_TRIANGLECOUNT NUMERIC(11,0) null,
	PARENT NUMERIC(6,0) null,
	ELEVATIONGRID VARBINARY(MAX) null,
	DTM_POINTS VARBINARY(MAX) null,
	DTM_TEXTURECOORDINATES VARBINARY(MAX) null,
	DTM_TRIANGLES VARBINARY(MAX) null,
	IMAGE NUMERIC(12,0) null,
	NAMEN VARCHAR(255) null, constraint AREA_PK primary key (AREA) ); 

-- Neue Tabelle AFFINETRAFO erstellen.
create table AFFINETRAFO (
	AFFINETRAFO NUMERIC(12,0) IDENTITY(1,1) not null,
	A0 NUMERIC(16,8) not null,
	B0 NUMERIC(16,8) not null,
	C0 NUMERIC(16,8) not null,
	A1 NUMERIC(16,8) not null,
	B1 NUMERIC(16,8) not null,
	C1 NUMERIC(16,8) not null, constraint AFFINETRAFO_PK primary key (AFFINETRAFO) ); 

-- Neue Tabelle COLOR erstellen.
create table COLOR (
	COLOR NUMERIC(12,0) IDENTITY(1,1) not null,
	RED NUMERIC(8,7) default 0 not null,
	GREEN NUMERIC(8,7) default 0 not null,
	BLUE NUMERIC(8,7) default 0 not null,
	constraint COLOR_PK primary key (COLOR) );


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle VERTEX hinzufgen.
create index IX_VERTEX_ELEMENT on VERTEX (
	ELEMENT ASC); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle UNITVERSION hinzufgen.
create index IX_UNITVERSION_UNIT on UNITVERSION (
	UNIT ASC); 


create unique index IX_UNITVERSION_VERSIONNUMBER on UNITVERSION (
	UNIT,
	VERSIONNUMBER); 


alter table UNITVERSION add constraint IX_UNITVERSION_VNUMBER_UC1 unique (
	UNIT,
	VERSIONNUMBER); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle UNITTREE hinzufgen.
alter table UNITTREE add constraint UNITTREE_UC1 unique (
	PAGE); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle UNITEXPORT hinzufgen.
create index IX_UNITEXPORT_UNIT on UNITEXPORT (
	UNIT ASC,
	LOD ASC); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle TEXTURE hinzufgen.
create index IX_TEXTURE_ELEMENT on TEXTURE (
	ELEMENT ASC); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle TEXCOORD hinzufgen.
create index IX_TEXCOORD_ELEMENT on TEXCOORD (
	ELEMENT ASC); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle OBJECT hinzufgen.
create index IX_OBJECT_UNIT on OBJECT (
	UNIT ASC); 


create index IX_OBJECT_UNITVERSION on OBJECT (
	UNITVERSION ASC); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle MODELUNIT hinzufgen.
create index IX_MODELUNIT_MODEL on MODELUNIT (
	MODEL ASC); 


create index IX_MODELUNIT_UNIT on MODELUNIT (
	UNIT ASC); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle INST_INFO_UNIQUE hinzufgen.
alter table INST_INFO add constraint INST_INFO_UNIQUE unique (
	SCHEMA_VERSION);

-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle FACE hinzufgen.
create index FACE_ELEMENT_FK on FACE (
	ELEMENT ASC); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle ELEMENTCONNECT hinzufgen.
create index IX_ELEMENTCONNECT_ELEMENT on ELEMENTCONNECT (
	ELEMENT ASC); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle ELEMENTCLASS hinzufgen.
alter table ELEMENTCLASS add constraint TC_ELEMENTCLASS25 unique (
	DESCRIPTION); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle ELEMENT hinzufgen.
create index IX_ELEMENT_LOD on ELEMENT (
	OBJECT ASC,
	LOD ASC); 


create index IX_ELEMENT_OBJECT on ELEMENT (
	OBJECT ASC); 


create index IX_ELEMENT_PARENT on ELEMENT (
	PARENT ASC); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle EDGETO hinzufgen.
create index IX_EDGETO_EDGELINE on EDGETO (
	EDGELINE ASC,
	ORDERING ASC); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle EDGELINE hinzufgen.
create index IX_EDGELINE_ELEMENT on EDGELINE (
	ELEMENT ASC); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle STRASSE hinzufgen.
alter table STREET_TEMPLATE add constraint STREET_UC1 unique (
	STREET_KEY); 


-- Verbleibende Schlssel, Abhngigkeiten und Indizes fr Tabelle BREAKLINE hinzufgen.
create index BREAKLINE_AREA_FK on BREAKLINE (
	AREA ASC); 


-- Fremdschlsselabhngigkeiten zu Tabelle VERTEX hinzufgen.
alter table VERTEX
	add constraint FK_VERTEX_ELEMENT foreign key (
		ELEMENT)
	 references ELEMENT (
		ELEMENT); 

-- Fremdschlsselabhngigkeiten zu Tabelle UNITVERSION hinzufgen.
alter table UNITVERSION
	add constraint UNIT_UNITVERSION_FK1 foreign key (
		UNIT)
	 references UNIT (
		UNIT); 

-- Fremdschlsselabhngigkeiten zu Tabelle UNITEXPORT hinzufgen.
alter table UNITEXPORT
	add constraint FK_UNITEXPORT_LOD foreign key (
		LOD)
	 references LOD (
		LOD) ON DELETE CASCADE; 

alter table UNITEXPORT
	add constraint FK_UNITEXPORT_UNIT foreign key (
		UNIT)
	 references UNIT (
		UNIT) ON DELETE CASCADE; 

alter table UNITEXPORT
	add constraint FK_UNITEXPORT8 foreign key (
		EXPORTDATA)
	 references EXPORTDATA (
		EXPORTDATA) ON DELETE CASCADE; 

-- Fremdschlsselabhngigkeiten zu Tabelle TEXTURE hinzufgen.
alter table TEXTURE
	add constraint IMAGE_TEXTURE_FK1 foreign key (
		IMAGE)
	 references IMAGE (
		IMAGE); 

alter table TEXTURE 
	add constraint FK_TEXTURE_COLOR foreign key (
		COLOR) 
	references COLOR (
		COLOR)

alter table TEXTURE
	add constraint TEXTURE_ELEMENT_FK foreign key (
		ELEMENT)
	 references ELEMENT (
		ELEMENT); 

-- Fremdschlsselabhngigkeiten zu Tabelle TEXCOORD hinzufgen.
alter table TEXCOORD
	add constraint FK_TEXCOORD9 foreign key (
		ELEMENT)
	 references ELEMENT (
		ELEMENT); 

-- Fremdschlsselabhngigkeiten zu Tabelle OBJECT hinzufgen.
alter table OBJECT
	add constraint FK_OBJECT_UNIT foreign key (
		UNIT)
	 references UNIT (
		UNIT); 

alter table OBJECT
	add constraint OBJECTCLASS_OBJECT_FK1 foreign key (
		OBJECTCLASS)
	 references OBJECTCLASS (
		OBJECTCLASS); 

alter table OBJECT
	add constraint UNITVERSION_OBJECT_FK1 foreign key (
		UNITVERSION)
	 references UNITVERSION (
		UNITVERSION); 

-- Fremdschlsselabhngigkeiten zu Tabelle MODELUNIT hinzufgen.
alter table MODELUNIT
	add constraint FK_MODELUNIT_MODEL foreign key (
		MODEL)
	 references MODEL (
		MODEL) ON DELETE CASCADE; 

alter table MODELUNIT
	add constraint FK_MODELUNIT_UNIT foreign key (
		UNIT)
	 references UNIT (
		UNIT) ON DELETE CASCADE; 

-- Fremdschlsselabhngigkeiten zu Tabelle MODEL hinzufgen.
alter table MODEL
	add constraint FK_MODEL_IMAGE foreign key (
		IMAGE)
	 references IMAGE (
		IMAGE); 

-- Fremdschlsselabhngigkeiten zu Tabelle IMGPYRAMID hinzufgen.
alter table IMGPYRAMID
	add constraint FK_IMAGEPYRAMID_IMAGE foreign key (
		IMAGE)
	 references IMAGE (
		IMAGE) ON DELETE CASCADE; 

-- Fremdschlsselabhngigkeiten zu Tabelle IMGORIENTATIONCONNECT hinzufgen.
alter table IMGORIENTATIONCONNECT
	add constraint FK_IMGORCONN_IMGORIENTATION foreign key (
		IMGORIENTATION)
	 references IMGORIENTATION (
		IMGORIENTATION) ON DELETE CASCADE; 

alter table IMGORIENTATIONCONNECT
	add constraint FK_IMGORCONN_EXTORIENTATION foreign key (
		EXTERIORORIENTATION)
	 references EXTERIORORIENTATION (
		EXTERIORORIENTATION) ON DELETE CASCADE; 

alter table IMGORIENTATIONCONNECT
	add constraint FK_IMGORCONN_INTORIENTATION foreign key (
		INTERIORORIENTATION)
	 references INTERIORORIENTATION (
		INTERIORORIENTATION) ON DELETE CASCADE; 

alter table IMGORIENTATIONCONNECT
	add constraint FK_IMGORCONN_AFFINETRAFO foreign key (
		AFFINETRAFO)
	 references AFFINETRAFO (
		AFFINETRAFO) ON DELETE CASCADE; 

-- Fremdschlsselabhngigkeiten zu Tabelle IMGORIENTATION hinzufgen.
alter table IMGORIENTATION
	add constraint FK_ORIENTATION10 foreign key (
		IMAGE)
	 references IMAGE (
		IMAGE); 

-- Fremdschlsselabhngigkeiten zu Tabelle FACE hinzufgen.
alter table FACE
	add constraint FACE_ELEMENT foreign key (
		ELEMENT)
	 references ELEMENT (
		ELEMENT); 

alter table FACE
	add constraint FACE_TEXTURE_FK foreign key (
		TEXTURE)
	 references TEXTURE (
		TEXTURE); 

-- Fremdschlsselabhngigkeiten zu Tabelle EXTRUSION hinzufgen.
alter table EXTRUSION
	add constraint EXTRSUSION_ELEMENT foreign key (
		ELEMENT)
	 references ELEMENT (
		ELEMENT); 

-- Fremdschlsselabhngigkeiten zu Tabelle ELEMENTCONNECT hinzufgen.
alter table ELEMENTCONNECT
	add constraint ELEMENT_ELEMENTCONNECT_FK1 foreign key (
		ELEMENT)
	 references ELEMENT (
		ELEMENT); 

alter table ELEMENTCONNECT
	add constraint ELEMENT_ELEMENTCONNECT_FK2 foreign key (
		ELEMENTCONNECT)
	 references ELEMENT (
		ELEMENT); 
		
-- Fremdschlsselabhngigkeiten zu Tabelle ELEMENT hinzufgen.
alter table ELEMENT
	add constraint FK_ELEMENT_OBJECT foreign key (
		OBJECT)
	 references OBJECT (
		OBJECT); 

alter table ELEMENT 
	add constraint ELEMENTCLASS_ELEMENT_FK1 foreign key (
		ELEMENTCLASS)
	 references ELEMENTCLASS(
	 	ELEMENTCLASS); 

-- Fremdschlsselabhngigkeiten zu Tabelle EDGETO hinzufgen.
alter table EDGETO
	add constraint FK_EDGETO_EDGELINE foreign key (
		EDGELINE)
	 references EDGELINE (
		EDGELINE); 

-- Fremdschlsselabhngigkeiten zu Tabelle EDGELINE hinzufgen.
alter table EDGELINE
	add constraint FK_EDGELINE_ELEMENT foreign key (
		ELEMENT)
	 references ELEMENT (
		ELEMENT); 

-- Fremdschlsselabhngigkeiten zu Tabelle AREAEXPORT hinzufgen.
alter table AREAEXPORT
	add constraint AREA_AREAEXPORT foreign key (
		AREA)
	 references AREA (
		AREA) ON DELETE CASCADE; 

-- Fremdschlsselabhngigkeiten zu Tabelle AREA hinzufgen.
alter table AREA
	add constraint AREA_AREA foreign key (
		PARENT)
	 references AREA (
		AREA); 



