-- 3 Possibilities for Addresses:
-- a) 2 views or tables in an external database/scheme with the following columns:
--    a1) STREET_NAME, STREET_ID
--    a2) ADR_X, ADR_Y, STREET_NUMBER, OBJECT_ID, OBJ_X, OBJ_Y, STREET_NAME, STREET_ID
--    and the synonyms GIS_V_STREETS and GIS_V_OBJECTADRESS refering to them.
-- b) 2 views in the CITYMAN-scheme with the columns as above viewing to external tables
--    and the synonyms GIS_V_STREETS and GIS_V_OBJECTADRESS refering to them.
-- c) 2 tables in the CITYMAN-scheme with the columns as above
--    and the synonyms GIS_V_STREETS and GIS_V_OBJECTADRESS refering to them.
-- Variante (c) is installed per default (with table names STREET_TEMPLATE and ADDRESS_TEMPLATE)
-- and can be changed interactively afterwards.

-- The Following two views are only as template for variante (b)

If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'V_ADDRESS'
            AND type = 'V')
	DROP VIEW V_ADDRESS
GO 
CREATE VIEW V_ADDRESS (ADR_X,
		ADR_Y,STREET_NUMBER,OBJECT_ID,OBJ_X,OBJ_Y,
		STREET_NAME,STREET_ID) AS 
	select ADDRESS_TEMPLATE.ADR_X, ADDRESS_TEMPLATE.ADR_Y, 
	ADDRESS_TEMPLATE.STREET_NUMBER, ADDRESS_TEMPLATE.OBJECT_ID, 
	ADDRESS_TEMPLATE.OBJ_X, ADDRESS_TEMPLATE.OBJ_Y, 
	STREET_TEMPLATE.NAME as STREET_NAME,
	STREET_TEMPLATE.STREET_KEY as STREET_ID 
	from ADDRESS_TEMPLATE, STREET_TEMPLATE 
	WHERE ( ADDRESS_TEMPLATE.STREET_KEY = STREET_TEMPLATE.STREET_KEY )
GO

If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'V_STREET'
            AND type = 'V')
	DROP VIEW V_STREET
GO 
CREATE VIEW V_STREET (STREET_NAME, STREET_ID) AS 
	select NAME as STREET_NAME, STREET_KEY as STREET_ID 
	from STREET_TEMPLATE
GO

-- The following views are obligatory! They use the synonym GIS_V_OBJECTADRESS

If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'V_GIS_MODELOBJECTS'
            AND type = 'V')
	DROP VIEW V_GIS_MODELOBJECTS
GO 
CREATE VIEW V_GIS_MODELOBJECTS as 
	select MODELUNIT.MODEL, UNIT.UNIT, UNIT_NUMBER, UNITID, GIS_V_OBJECTADRESS.STREET_NAME, UNIT.NAMEN 
	from MODELUNIT, UNIT, UNITGIS, GIS_V_OBJECTADRESS 
	where ( ( UNIT.UNIT = MODELUNIT.UNIT ) and ( UNITGIS.UNIT = UNIT.UNIT ) and ( GIS_V_OBJECTADRESS.OBJECT_ID = UNITGIS.GISKEY ) )
GO

If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'V_GIS_OBJECTS'
            AND type = 'V')
	DROP VIEW V_GIS_OBJECTS
GO 
CREATE VIEW V_GIS_OBJECTS as	
	select UNIT.UNIT, UNIT_NUMBER, UNITID, GIS_V_OBJECTADRESS.STREET_NAME, UNIT.NAMEN
	from UNIT, UNITGIS, GIS_V_OBJECTADRESS
	where ( UNITGIS.UNIT = UNIT.UNIT and GIS_V_OBJECTADRESS.OBJECT_ID = UNITGIS.GISKEY )
GO

If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'V_MODEL_TEXTURE_IMAGE'
            AND type = 'V')
	DROP VIEW V_MODEL_TEXTURE_IMAGE
GO 
CREATE VIEW V_MODEL_TEXTURE_IMAGE (MODEL, IMAGE) AS 
    select distinct MODELUNIT.MODEL, IMAGE.IMAGE
from MODELUNIT, UNIT, OBJECT, ELEMENT, TEXTURE, IMAGE
WHERE
( ( UNIT.UNIT = MODELUNIT.UNIT ) AND
( OBJECT.UNIT = UNIT.UNIT ) AND
( ELEMENT.OBJECT = OBJECT.OBJECT ) AND
( TEXTURE.ELEMENT = ELEMENT.ELEMENT ) AND
( IMAGE.IMAGE =  TEXTURE.IMAGE))
GO

If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'V_MODELUNITS'
            AND type = 'V')
	DROP VIEW V_MODELUNITS
GO 
CREATE VIEW V_MODELUNITS as
	select MODEL.NAMEN as MODEL_NAMEN, UNIT.NAMEN
    as UNIT_NAMEN, UNIT.UNIT_NUMBER, UNIT.UNITID, MODELUNIT.MODEL, MODELUNIT.UNIT
    from MODEL, UNIT, MODELUNIT
    where ( ( MODELUNIT.MODEL = MODEL.MODEL ) and ( UNIT.UNIT = MODELUNIT.UNIT ) )
GO

If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'V_UNITEXPORT'
            AND type = 'V')
	DROP VIEW V_UNITEXPORT
GO 
CREATE VIEW V_UNITEXPORT (DATA,NAMEN,
    MODEL,UNIT,EXPORTDATA,LOD,TYPE) AS 
    select EXPORTDATA.DATA, MODEL.NAMEN, 
    MODELUNIT.MODEL, MODELUNIT.UNIT, UNITEXPORT.
    EXPORTDATA, UNITEXPORT.LOD, UNITEXPORT.TYPE
    from EXPORTDATA, MODEL, MODELUNIT,
    UNITEXPORT
    WHERE ( ( MODELUNIT.MODEL = MODEL.MODEL )
    AND ( UNITEXPORT.UNIT =  MODELUNIT.UNIT)
    AND ( EXPORTDATA.EXPORTDATA =   UNITEXPORT.EXPORTDATA)  )
GO

If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'V_UNIT_TEXTURE_IMAGE'
            AND type = 'V')
	DROP VIEW V_UNIT_TEXTURE_IMAGE
GO 
CREATE VIEW V_UNIT_TEXTURE_IMAGE as	
	select distinct UNIT.UNIT, UNITVERSION.UNITVERSION, IMAGE.IMAGE
	from UNIT, UNITVERSION, OBJECT, ELEMENT, TEXTURE, IMAGE
	WHERE
	( ( UNITVERSION.UNIT = UNIT.UNIT ) AND
	( OBJECT.UNITVERSION = UNITVERSION.UNITVERSION ) AND
	( ELEMENT.OBJECT = OBJECT.OBJECT ) AND
	( TEXTURE.ELEMENT = ELEMENT.ELEMENT ) AND
	( IMAGE.IMAGE =  TEXTURE.IMAGE))
GO

-- views fr die letzte gltige/stabile Versionsnummer
If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'V_LAST_VALID_VERSIONNUMBER'
            AND type = 'V')
	DROP VIEW V_LAST_VALID_VERSIONNUMBER
GO 
CREATE VIEW V_LAST_VALID_VERSIONNUMBER as	
	select UNITVERSION.UNIT, max(UNITVERSION.VERSIONNUMBER) as VERSIONNUMBER
	from UNITVERSION
	where UNITVERSION.STATE <> 3
	group by UNITVERSION.UNIT
GO
	
If Exists ( SELECT name 
            FROM sysobjects  
            WHERE name = 'V_LAST_STABLE_VERSIONNUMBER'
            AND type = 'V')
	DROP VIEW V_LAST_STABLE_VERSIONNUMBER
GO 
CREATE VIEW V_LAST_STABLE_VERSIONNUMBER as	
	select UNITVERSION.UNIT, max(UNITVERSION.VERSIONNUMBER) as VERSIONNUMBER
	from UNITVERSION
	where UNITVERSION.STATE <> 2 and UNITVERSION.STATE <> 3
	group by UNITVERSION.UNIT
GO


